pub enum Format {
AUTO,
XZ,
ALONE,
RAW,
}Expand description
Possible formats
Variants
AUTO
Auto select the format, for compression this is XZ, for decompression it will be determined by the compressed input.
XZ
The .xz format (default)
ALONE
Legacy .lzma format.
RAW
Raw data stream